@@ -52,7 +52,7 @@ class TreesappTester(unittest.TestCase):
         self.assertEqual(len(pre_lines), len(post_lines))
         # Ensure the name of the sample is substituted for the sample ID
         self.assertEqual({"test_TarA.1"}, set([line[0] for line in post_lines]))
-        self.assertEqual(1773, round(sum(abund_dict.values())))
+        self.assertEqual(148, round(sum(abund_dict.values())))
         # Replace the classification table
         copyfile(os.path.join(self.ts_assign_output, "tmp.tsv"), classification_table)
         os.remove(os.path.join(self.ts_assign_output, "tmp.tsv"))
@@ -91,8 +91,8 @@ class TreesappTester(unittest.TestCase):
         assign(assign_commands_list)
         lines = read_classification_table("./TreeSAPP_assign/final_outputs/marker_contig_map.tsv")
         self.assertEqual(6, len(lines))
-        classified_seqs = [line[1] for line in lines]
-        self.assertTrue("LYOS01000003.1:168824-170509_1 # 1 # 1686 # 1 # ID=3_1;partial=10;start_type=Edge;rbs_motif=None;rbs_spacer=None;gc_cont=0.493" in classified_seqs)
+        classified_seqs = [line[1].split()[0] for line in lines]
+        self.assertTrue("LYOS01000003.1:168824-170509_1" in classified_seqs)
         self.assertTrue(os.path.isfile("./TreeSAPP_assign/final_outputs/marker_test_suite_classified.fna"))
         return
 
@@ -138,15 +138,11 @@ class TreesappTester(unittest.TestCase):
         test_refpkg.f__json = "./TreeSAPP_create/final_outputs/Crt_build.pkl"
         test_refpkg.slurp()
         self.assertTrue(test_refpkg.validate())
-        self.assertEqual(69, test_refpkg.num_seqs)
+        self.assertEqual(77, test_refpkg.num_seqs)
         self.assertEqual(2, len(test_refpkg.pfit))
         self.assertTrue(test_refpkg.pfit[0] < 0)
-        return
 
-    def test_create_eggnog(self):
-        from treesapp.commands import create
-        from treesapp.refpkg import ReferencePackage
-        from .testing_utils import get_test_data
+        # Test with different header format (EggNOG), infer phylogeny with RAxML-NG and skip training
         create_commands_list = ["--fastx_input", get_test_data("ENOG4111FIN.txt"),
                                 "--output", "./TreeSAPP_create",
                                 "--refpkg_name", "PuhA",
@@ -167,12 +163,8 @@ class TreesappTester(unittest.TestCase):
         self.assertTrue(test_refpkg.validate())
         self.assertEqual(39, test_refpkg.num_seqs)
         self.assertEqual("LG+F+R4", test_refpkg.sub_model)
-        return
 
-    def test_create_accession2lin(self):
-        from treesapp.commands import create
-        from treesapp.refpkg import ReferencePackage
-        from .testing_utils import get_test_data
+        # Test with another header format and the lineages are provided in an accession2lin table
         cmd_list = ["--fastx_input", get_test_data("PF01280_test.fasta"),
                     "--accession2lin", get_test_data("PF01280_test.tsv"),
                     "--output", "./TreeSAPP_create",
@@ -272,6 +264,8 @@ class TreesappTester(unittest.TestCase):
         test_refpkg.f__json = "./TreeSAPP_package/McrA_build.pkl"
         test_refpkg.slurp()
         self.assertFalse(test_refpkg.validate())
+        with pytest.raises(SystemExit):
+            package(["rename", "-h"])
         return
 
     def test_mcc_calculator(self):
