@@ -11,7 +11,7 @@ from pyfastx import Fasta, Fastq
 from pyfastxcli import fastx_format_check
 from collections import namedtuple
 
-from treesapp.utilities import median, reformat_string, rekey_dict
+from treesapp.utilities import median, rekey_dict
 
 
 def fastx_split(fastx: str, outdir: str, file_num=1) -> list:
@@ -27,12 +27,12 @@ def fastx_split(fastx: str, outdir: str, file_num=1) -> list:
     return split_files
 
 
-def split_seq_writer_helper(fasta_string: str, fh, max_file_size: int):
-    fh.write(fasta_string)
+def split_seq_writer_helper(fastx_string: str, fh, curr_file_size: int, max_file_size: int):
+    fh.write(fastx_string)
 
     # Reduce the number of checks
     fh.seek(0, 2)
-    if fh.tell() > max_file_size:
+    if curr_file_size > max_file_size:
         fh.close()
         fh = None
     return fh
@@ -60,8 +60,17 @@ def spawn_new_file(file_num, outdir, file_name, ext="fasta"):
     return fh, file_num
 
 
-def parameterize_sub_file_size(file_name: str, num_files: int, max_seqs: int):
-    # Determine the size of the FASTA file instead of building an index
+def parameterize_sub_file_size(file_name: str, num_files: int, max_seqs: int, record_len=2) -> (int, int):
+    """
+    Calculates the number of lines or bytes to be included in each sub-file chunk
+
+    :param file_name: Path to a file to calculate the split-size for
+    :param num_files: Number of files to break the file into
+    :param max_seqs: Maximum number of sequences in each chunk descired
+    :param record_len: The number of lines in a sequence record e.g. 2 for fasta and 4 for fastq
+    :return:
+    """
+    # Determine the size of the FASTA/FASTQ file instead of building an index
     f_size = os.path.getsize(file_name)
 
     if num_files > 1:
@@ -105,6 +114,7 @@ def split_fa(fastx: str, outdir: str, file_num=1, max_seq_count=0):
     max_file_size, max_seq_count = parameterize_sub_file_size(fastx, file_num, max_seq_count)
 
     seq_write = 0
+    curr_file_size = 0
     max_buffer_size = min(1E5, max_file_size)  # Controls how often the strings are written to the file
     fasta_string = ""  # Stores the intermediate fasta strings
     fh = None  # File handler
@@ -115,10 +125,13 @@ def split_fa(fastx: str, outdir: str, file_num=1, max_seq_count=0):
         seq_write += 1
         # Batch write
         if len(fasta_string) >= max_buffer_size and seq_write >= max_seq_count:
+            curr_file_size += fasta_string.__sizeof__()
             if not fh:
                 fh, file_num = spawn_new_file(file_num, outdir, file_name)
                 outputs.append(fh.name)
-            fh = split_seq_writer_helper(fasta_string, fh, max_file_size)
+            fh = split_seq_writer_helper(fasta_string, fh, curr_file_size, max_file_size)
+            if fh is None:
+                curr_file_size = 0
             fasta_string = ""
             seq_write = 0
 
@@ -167,19 +180,26 @@ def fq2fa(fastx: str, outdir: str, file_num=1, max_seq_count=0) -> list:
 
     seq_write = 0
     max_buffer_size = min(1E5, max_file_size)  # Controls how often the strings are written to the file
+    buff_size = 0
+    curr_file_size = 0
     fasta_string = ""  # Stores the intermediate fasta strings
     fh = None  # File handler
     file_num = 0  # The current file number
 
-    for read_name, seq, _ in fq:  # type: (str, str)
+    for read_name, seq, qual in fq:  # type: (str, str)
+        buff_size += str(read_name + seq + qual).__sizeof__()
         fasta_string += ">%s\n%s\n" % (read_name, seq)
         seq_write += 1
         # Batch write
-        if len(fasta_string) >= max_buffer_size and seq_write >= max_seq_count:
+        if buff_size >= max_buffer_size and seq_write >= max_seq_count:
+            curr_file_size += buff_size
             if not fh:
                 fh, file_num = spawn_new_file(file_num, outdir, file_name)
                 outputs.append(fh.name)
-            fh = split_seq_writer_helper(fasta_string, fh, max_file_size)
+            fh = split_seq_writer_helper(fasta_string, fh, curr_file_size, max_file_size)
+            if fh is None:
+                curr_file_size = 0
+            buff_size = 0
             fasta_string = ""
             seq_write = 0
 
@@ -228,7 +248,6 @@ class Header:
     def __init__(self, header):
         self.original = header
         self.treesapp_num_id = 0
-        self.formatted = ""
         self.post_align = ""
         self.first_split = ""
         self.accession = ""
@@ -274,7 +293,6 @@ def register_headers(header_list: list, drop=True) -> dict:
         else:
             dup_checker.add(header)
         new_header = Header(header)
-        new_header.formatted = reformat_string(header)
         new_header.first_split = header.split()[0]
         new_header.treesapp_num_id = str(acc)
         header_registry[str(acc)] = new_header
@@ -341,16 +359,6 @@ class FASTA:
     def original_header_map(self):
         return {self.header_registry[index].original: [self.header_registry[index]] for index in self.header_registry}
 
-    # def formatted_header_map(self):
-    #     header_map = dict()
-    #     for header in self.header_registry.values():  # type: Header
-    #         f_h = header.formatted
-    #         if f_h in header_map:
-    #             header_map[f_h].append(header)
-    #         else:
-    #             header_map[f_h] = [header]
-    #     return header_map
-
     def first_split_header_map(self):
         header_map = dict()
         for header in self.header_registry.values():  # type: Header
@@ -384,22 +392,13 @@ class FASTA:
             return [self.header_registry[index].original for index in sorted(self.header_registry, key=int)]
         elif name_format == "first_split":
             return [self.header_registry[index].first_split for index in sorted(self.header_registry, key=int)]
-        elif name_format == "formatted":
-            return [self.header_registry[index].formatted for index in sorted(self.header_registry, key=int)]
         elif name_format == "num":
             return [index for index in sorted(self.header_registry, key=int)]
         else:
             logging.error("Unrecognized Header format '" + name_format + "'." +
-                          " Options are 'original', 'formatted', 'first_split' and 'num'.\n")
+                          " Options are 'original', 'first_split' and 'num'.\n")
             sys.exit(5)
 
-    def create_header_mapping_table(self):
-        table_str = "\t".join(["TreeSAPP number", "Accession", "Original", "Formatted"]) + "\n"
-        for acc in sorted(self.header_registry):
-            header = self.header_registry[acc]  # type: Header
-            table_str += "\t".join([header.treesapp_num_id, header.accession, header.original, header.formatted]) + "\n"
-        return table_str
-
     def keep_only(self, header_subset: list, superset=False):
         """
         Removes all entries from self.fasta_dict and self.header_registry that are not in header_subset.
@@ -476,7 +475,6 @@ class FASTA:
         """
         mapping_dict = dict()
         mapping_dict.update(self.original_header_map())
-        # mapping_dict.update(self.formatted_header_map())
         mapping_dict.update(self.first_split_header_map())
         return mapping_dict
 
@@ -495,8 +493,6 @@ class FASTA:
                 new_header = header.original
             elif index_replace == "first_split":
                 new_header = header.first_split
-            elif index_replace == "formatted":
-                new_header = header.formatted
             elif index_replace == "num":
                 new_header = acc
             elif index_replace == "accession":
@@ -508,8 +504,6 @@ class FASTA:
             # NOTE: Using .first_split may be lossy if duplicates exist. This will _not_ propagate under current scheme.
             if header.original in self.fasta_dict:
                 repl_fasta_dict[new_header] = self.fasta_dict[header.original]
-            elif header.formatted in self.fasta_dict:
-                repl_fasta_dict[new_header] = self.fasta_dict[header.formatted]
             elif acc in self.fasta_dict:
                 repl_fasta_dict[new_header] = self.fasta_dict[acc]
             elif header.first_split in self.fasta_dict:
@@ -831,19 +825,25 @@ def format_read_fasta(fasta_input: str, molecule: str, subset=None, min_seq_leng
     :return: A Python dictionary with headers as keys and sequences as values
     """
     start = time()
+    formatted_fasta_dict = {}
+    bad_seqs = set()
 
     if molecule == "prot":
         bad_chars = re.compile(r"[OUou\d]")
     else:
         bad_chars = re.compile(r"[EFIJLOPQZefijlopqz\d]")
-    bad_seqs = set()
 
     if subset and type(subset) is not set:
         logging.error("Unexpected type of subset: {} instead of set.\n".format(type(subset)))
         sys.exit(13)
 
-    formatted_fasta_dict = {}
-    for name, seq in Fasta(fasta_input, build_index=False, full_name=True):  # type: (str, str)
+    try:
+        py_fa = Fasta(fasta_input, build_index=False, full_name=True)
+    except RuntimeError as error:
+        logging.debug(str(error)+"\n")
+        return formatted_fasta_dict
+
+    for name, seq in py_fa:  # type: (str, str)
         if len(seq) < min_seq_length:
             continue
         if subset:
